@@ -41,3 +41,6 @@ from pybsc.opener import opener
 from pybsc.md5sum_utils import checksum_md5
 
 from pybsc.stdout_utils import suppress_stdout
+
+from pybsc.str_utils import removesuffix
+from pybsc.str_utils import remove_non_ascii
